==> javascript-frontend-2.10-sources.jar: org/sonar/javascript/tree/impl/statement/DebuggerStatementTreeImpl.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.javascript.tree.impl.statement;

import com.google.common.collect.Iterators;
import java.util.Iterator;
import javax.annotation.Nullable;
import org.sonar.javascript.tree.impl.JavaScriptTree;
import org.sonar.javascript.tree.impl.lexical.InternalSyntaxToken;
import org.sonar.plugins.javascript.api.tree.Tree;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;
import org.sonar.plugins.javascript.api.tree.statement.DebuggerStatementTree;
import org.sonar.plugins.javascript.api.visitors.TreeVisitor;

public class DebuggerStatementTreeImpl extends JavaScriptTree implements DebuggerStatementTree {

  private final SyntaxToken debuggerKeyword;
  private final SyntaxToken semicolonToken;

  public DebuggerStatementTreeImpl(InternalSyntaxToken debuggerKeyword, SyntaxToken semicolonToken) {
    this.debuggerKeyword = debuggerKeyword;
    this.semicolonToken = semicolonToken;

  }

  @Override
  public Kind getKind() {
    return Kind.DEBUGGER_STATEMENT;
  }

  @Override
  public SyntaxToken debuggerKeyword() {
    return debuggerKeyword;
  }

  @Nullable
  @Override
  public SyntaxToken semicolonToken() {
    return semicolonToken;
  }

  @Override
  public Iterator<Tree> childrenIterator() {
    return Iterators.forArray((Tree) debuggerKeyword, semicolonToken);
  }

  @Override
  public void accept(TreeVisitor visitor) {
    visitor.visitDebugger(this);
  }
}

==> javascript-frontend-2.14-sources.jar: org/sonar/javascript/tree/impl/statement/DebuggerStatementTreeImpl.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.javascript.tree.impl.statement;

import com.google.common.collect.Iterators;
import java.util.Iterator;
import javax.annotation.Nullable;
import org.sonar.javascript.tree.impl.JavaScriptTree;
import org.sonar.javascript.tree.impl.lexical.InternalSyntaxToken;
import org.sonar.plugins.javascript.api.tree.Tree;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;
import org.sonar.plugins.javascript.api.tree.statement.DebuggerStatementTree;
import org.sonar.plugins.javascript.api.visitors.DoubleDispatchVisitor;

public class DebuggerStatementTreeImpl extends JavaScriptTree implements DebuggerStatementTree {

  private final SyntaxToken debuggerKeyword;
  private final SyntaxToken semicolonToken;

  public DebuggerStatementTreeImpl(InternalSyntaxToken debuggerKeyword, SyntaxToken semicolonToken) {
    this.debuggerKeyword = debuggerKeyword;
    this.semicolonToken = semicolonToken;

  }

  @Override
  public Kind getKind() {
    return Kind.DEBUGGER_STATEMENT;
  }

  @Override
  public SyntaxToken debuggerKeyword() {
    return debuggerKeyword;
  }

  @Nullable
  @Override
  public SyntaxToken semicolonToken() {
    return semicolonToken;
  }

  @Override
  public Iterator<Tree> childrenIterator() {
    return Iterators.forArray((Tree) debuggerKeyword, semicolonToken);
  }

  @Override
  public void accept(DoubleDispatchVisitor visitor) {
    visitor.visitDebugger(this);
  }
}
